@@ -128,161 +128,6 @@ arv_acquisition_mode_get_type (void)
 	return the_type;
 }
 
-GType
-arv_pixel_format_get_type (void)
-{
-	static GType the_type = 0;
-
-	if (the_type == 0)
-	{
-		static const GEnumValue values[] = {
-			{ ARV_PIXEL_FORMAT_MONO_8,
-			  "ARV_PIXEL_FORMAT_MONO_8",
-			  "mono-8" },
-			{ ARV_PIXEL_FORMAT_MONO_8_SIGNED,
-			  "ARV_PIXEL_FORMAT_MONO_8_SIGNED",
-			  "mono-8-signed" },
-			{ ARV_PIXEL_FORMAT_MONO_10,
-			  "ARV_PIXEL_FORMAT_MONO_10",
-			  "mono-10" },
-			{ ARV_PIXEL_FORMAT_MONO_10_PACKED,
-			  "ARV_PIXEL_FORMAT_MONO_10_PACKED",
-			  "mono-10-packed" },
-			{ ARV_PIXEL_FORMAT_MONO_12,
-			  "ARV_PIXEL_FORMAT_MONO_12",
-			  "mono-12" },
-			{ ARV_PIXEL_FORMAT_MONO_12_PACKED,
-			  "ARV_PIXEL_FORMAT_MONO_12_PACKED",
-			  "mono-12-packed" },
-			{ ARV_PIXEL_FORMAT_MONO_14,
-			  "ARV_PIXEL_FORMAT_MONO_14",
-			  "mono-14" },
-			{ ARV_PIXEL_FORMAT_MONO_16,
-			  "ARV_PIXEL_FORMAT_MONO_16",
-			  "mono-16" },
-			{ ARV_PIXEL_FORMAT_BAYER_GR_8,
-			  "ARV_PIXEL_FORMAT_BAYER_GR_8",
-			  "bayer-gr-8" },
-			{ ARV_PIXEL_FORMAT_BAYER_RG_8,
-			  "ARV_PIXEL_FORMAT_BAYER_RG_8",
-			  "bayer-rg-8" },
-			{ ARV_PIXEL_FORMAT_BAYER_GB_8,
-			  "ARV_PIXEL_FORMAT_BAYER_GB_8",
-			  "bayer-gb-8" },
-			{ ARV_PIXEL_FORMAT_BAYER_BG_8,
-			  "ARV_PIXEL_FORMAT_BAYER_BG_8",
-			  "bayer-bg-8" },
-			{ ARV_PIXEL_FORMAT_BAYER_GR_10,
-			  "ARV_PIXEL_FORMAT_BAYER_GR_10",
-			  "bayer-gr-10" },
-			{ ARV_PIXEL_FORMAT_BAYER_RG_10,
-			  "ARV_PIXEL_FORMAT_BAYER_RG_10",
-			  "bayer-rg-10" },
-			{ ARV_PIXEL_FORMAT_BAYER_GB_10,
-			  "ARV_PIXEL_FORMAT_BAYER_GB_10",
-			  "bayer-gb-10" },
-			{ ARV_PIXEL_FORMAT_BAYER_BG_10,
-			  "ARV_PIXEL_FORMAT_BAYER_BG_10",
-			  "bayer-bg-10" },
-			{ ARV_PIXEL_FORMAT_BAYER_GR_12,
-			  "ARV_PIXEL_FORMAT_BAYER_GR_12",
-			  "bayer-gr-12" },
-			{ ARV_PIXEL_FORMAT_BAYER_RG_12,
-			  "ARV_PIXEL_FORMAT_BAYER_RG_12",
-			  "bayer-rg-12" },
-			{ ARV_PIXEL_FORMAT_BAYER_GB_12,
-			  "ARV_PIXEL_FORMAT_BAYER_GB_12",
-			  "bayer-gb-12" },
-			{ ARV_PIXEL_FORMAT_BAYER_BG_12,
-			  "ARV_PIXEL_FORMAT_BAYER_BG_12",
-			  "bayer-bg-12" },
-			{ ARV_PIXEL_FORMAT_BAYER_BG_12_PACKED,
-			  "ARV_PIXEL_FORMAT_BAYER_BG_12_PACKED",
-			  "bayer-bg-12-packed" },
-			{ ARV_PIXEL_FORMAT_RGB_8_PACKED,
-			  "ARV_PIXEL_FORMAT_RGB_8_PACKED",
-			  "rgb-8-packed" },
-			{ ARV_PIXEL_FORMAT_BGR_8_PACKED,
-			  "ARV_PIXEL_FORMAT_BGR_8_PACKED",
-			  "bgr-8-packed" },
-			{ ARV_PIXEL_FORMAT_RGBA_8_PACKED,
-			  "ARV_PIXEL_FORMAT_RGBA_8_PACKED",
-			  "rgba-8-packed" },
-			{ ARV_PIXEL_FORMAT_BGRA_8_PACKED,
-			  "ARV_PIXEL_FORMAT_BGRA_8_PACKED",
-			  "bgra-8-packed" },
-			{ ARV_PIXEL_FORMAT_RGB_10_PACKED,
-			  "ARV_PIXEL_FORMAT_RGB_10_PACKED",
-			  "rgb-10-packed" },
-			{ ARV_PIXEL_FORMAT_BGR_10_PACKED,
-			  "ARV_PIXEL_FORMAT_BGR_10_PACKED",
-			  "bgr-10-packed" },
-			{ ARV_PIXEL_FORMAT_RGB_12_PACKED,
-			  "ARV_PIXEL_FORMAT_RGB_12_PACKED",
-			  "rgb-12-packed" },
-			{ ARV_PIXEL_FORMAT_BGR_12_PACKED,
-			  "ARV_PIXEL_FORMAT_BGR_12_PACKED",
-			  "bgr-12-packed" },
-			{ ARV_PIXEL_FORMAT_YUV_411_PACKED,
-			  "ARV_PIXEL_FORMAT_YUV_411_PACKED",
-			  "yuv-411-packed" },
-			{ ARV_PIXEL_FORMAT_YUV_422_PACKED,
-			  "ARV_PIXEL_FORMAT_YUV_422_PACKED",
-			  "yuv-422-packed" },
-			{ ARV_PIXEL_FORMAT_YUV_444_PACKED,
-			  "ARV_PIXEL_FORMAT_YUV_444_PACKED",
-			  "yuv-444-packed" },
-			{ ARV_PIXEL_FORMAT_RGB_8_PLANAR,
-			  "ARV_PIXEL_FORMAT_RGB_8_PLANAR",
-			  "rgb-8-planar" },
-			{ ARV_PIXEL_FORMAT_RGB_10_PLANAR,
-			  "ARV_PIXEL_FORMAT_RGB_10_PLANAR",
-			  "rgb-10-planar" },
-			{ ARV_PIXEL_FORMAT_RGB_12_PLANAR,
-			  "ARV_PIXEL_FORMAT_RGB_12_PLANAR",
-			  "rgb-12-planar" },
-			{ ARV_PIXEL_FORMAT_RGB_16_PLANAR,
-			  "ARV_PIXEL_FORMAT_RGB_16_PLANAR",
-			  "rgb-16-planar" },
-			{ ARV_PIXEL_FORMAT_YUV_422_YUYV_PACKED,
-			  "ARV_PIXEL_FORMAT_YUV_422_YUYV_PACKED",
-			  "yuv-422-yuyv-packed" },
-			{ ARV_PIXEL_FORMAT_CUSTOM_BAYER_GR_12_PACKED,
-			  "ARV_PIXEL_FORMAT_CUSTOM_BAYER_GR_12_PACKED",
-			  "custom-bayer-gr-12-packed" },
-			{ ARV_PIXEL_FORMAT_CUSTOM_BAYER_RG_12_PACKED,
-			  "ARV_PIXEL_FORMAT_CUSTOM_BAYER_RG_12_PACKED",
-			  "custom-bayer-rg-12-packed" },
-			{ ARV_PIXEL_FORMAT_CUSTOM_BAYER_GB_12_PACKED,
-			  "ARV_PIXEL_FORMAT_CUSTOM_BAYER_GB_12_PACKED",
-			  "custom-bayer-gb-12-packed" },
-			{ ARV_PIXEL_FORMAT_CUSTOM_BAYER_BG_12_PACKED,
-			  "ARV_PIXEL_FORMAT_CUSTOM_BAYER_BG_12_PACKED",
-			  "custom-bayer-bg-12-packed" },
-			{ ARV_PIXEL_FORMAT_CUSTOM_YUV_422_YUYV_PACKED,
-			  "ARV_PIXEL_FORMAT_CUSTOM_YUV_422_YUYV_PACKED",
-			  "custom-yuv-422-yuyv-packed" },
-			{ ARV_PIXEL_FORMAT_CUSTOM_BAYER_GR_16,
-			  "ARV_PIXEL_FORMAT_CUSTOM_BAYER_GR_16",
-			  "custom-bayer-gr-16" },
-			{ ARV_PIXEL_FORMAT_CUSTOM_BAYER_RG_16,
-			  "ARV_PIXEL_FORMAT_CUSTOM_BAYER_RG_16",
-			  "custom-bayer-rg-16" },
-			{ ARV_PIXEL_FORMAT_CUSTOM_BAYER_GB_16,
-			  "ARV_PIXEL_FORMAT_CUSTOM_BAYER_GB_16",
-			  "custom-bayer-gb-16" },
-			{ ARV_PIXEL_FORMAT_CUSTOM_BAYER_BG_16,
-			  "ARV_PIXEL_FORMAT_CUSTOM_BAYER_BG_16",
-			  "custom-bayer-bg-16" },
-			{ 0, NULL, NULL }
-		};
-		the_type = g_enum_register_static (
-				g_intern_static_string ("ArvPixelFormat"),
-				values);
-	}
-	return the_type;
-}
-
 #include "arvdebug.h"
 
 GType
@@ -580,6 +425,37 @@ arv_gc_register_node_type_get_type (void)
 	return the_type;
 }
 
+#include "arvdevice.h"
+
+GType
+arv_device_status_get_type (void)
+{
+	static GType the_type = 0;
+
+	if (the_type == 0)
+	{
+		static const GEnumValue values[] = {
+			{ ARV_DEVICE_STATUS_UNKNOWN,
+			  "ARV_DEVICE_STATUS_UNKNOWN",
+			  "unknown" },
+			{ ARV_DEVICE_STATUS_SUCCESS,
+			  "ARV_DEVICE_STATUS_SUCCESS",
+			  "success" },
+			{ ARV_DEVICE_STATUS_TIMEOUT,
+			  "ARV_DEVICE_STATUS_TIMEOUT",
+			  "timeout" },
+			{ ARV_DEVICE_STATUS_WRITE_ERROR,
+			  "ARV_DEVICE_STATUS_WRITE_ERROR",
+			  "write-error" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_enum_register_static (
+				g_intern_static_string ("ArvDeviceStatus"),
+				values);
+	}
+	return the_type;
+}
+
 #include "arvstream.h"
 
 GType
