@@ -20,8 +20,6 @@
  * Author: Emmanuel Pacaud <emmanuel@gnome.org>
  */
 
-#define GLIB_DISABLE_DEPRECATION_WARNINGS
-
 #include <arv.h>
 #include <stdlib.h>
 #include <string.h>
@@ -165,7 +163,7 @@ arv_fake_gv_camera_thread (void *user_data)
 
 				packet_size = ARV_FAKE_GV_CAMERA_BUFFER_SIZE;
 				arv_gvsp_packet_new_data_block (image_buffer->frame_id, block_id,
-								data_size, image_buffer->data + offset,
+								data_size, ((char *) image_buffer->data) + offset,
 								packet_buffer, &packet_size);
 
 				g_socket_send_to (gv_camera->gvsp_socket, stream_address,
@@ -298,8 +296,7 @@ arv_fake_gv_camera_new (const char *interface_name)
 		goto INTERFACE_ERROR;
 
 	gv_camera->cancel = FALSE;
-	gv_camera->gvsp_thread = g_thread_create (arv_fake_gv_camera_thread,
-						  gv_camera, TRUE, NULL);
+	gv_camera->gvsp_thread = arv_g_thread_new ("arv_fake_gv_camera", arv_fake_gv_camera_thread, gv_camera);
 
 	return gv_camera;
 
@@ -468,8 +465,8 @@ main (int argc, char **argv)
 	GOptionContext *context;
 	GError *error = NULL;
 
-	g_thread_init (NULL);
-	g_type_init ();
+	arv_g_thread_init (NULL);
+	arv_g_type_init ();
 
 	context = g_option_context_new (NULL);
 	g_option_context_set_summary (context, "Fake GigEVision camera.");
