@@ -29,6 +29,7 @@
 #include <arvgvdevice.h>
 #include <arvgvcp.h>
 #include <arvdebug.h>
+#include <arvmisc.h>
 #include <glib/gprintf.h>
 #include <gio/gio.h>
 #include <sys/types.h>
@@ -392,7 +393,7 @@ arv_gv_interface_open_device (ArvInterface *interface, const char *device_id)
 }
 
 static ArvInterface *gv_interface = NULL;
-static GStaticMutex gv_interface_mutex = G_STATIC_MUTEX_INIT;
+ARV_DEFINE_STATIC_MUTEX (gv_interface_mutex);
 
 /**
  * arv_gv_interface_get_instance:
@@ -405,12 +406,12 @@ static GStaticMutex gv_interface_mutex = G_STATIC_MUTEX_INIT;
 ArvInterface *
 arv_gv_interface_get_instance (void)
 {
-	g_static_mutex_lock (&gv_interface_mutex);
+	arv_g_mutex_lock (&gv_interface_mutex);
 
 	if (gv_interface == NULL)
 		gv_interface = g_object_new (ARV_TYPE_GV_INTERFACE, NULL);
 
-	g_static_mutex_unlock (&gv_interface_mutex);
+	arv_g_mutex_unlock (&gv_interface_mutex);
 
 	return ARV_INTERFACE (gv_interface);
 }
@@ -418,14 +419,14 @@ arv_gv_interface_get_instance (void)
 void
 arv_gv_interface_destroy_instance (void)
 {
-	g_static_mutex_lock (&gv_interface_mutex);
+	arv_g_mutex_lock (&gv_interface_mutex);
 
 	if (gv_interface != NULL) {
 		g_object_unref (gv_interface);
 		gv_interface = NULL;
 	}
 
-	g_static_mutex_unlock (&gv_interface_mutex);
+	arv_g_mutex_unlock (&gv_interface_mutex);
 }
 
 static void
