@@ -29,6 +29,8 @@ G_BEGIN_DECLS
 
 unsigned int 		arv_get_n_interfaces 		(void);
 const char * 		arv_get_interface_id 		(unsigned int index);
+void 			arv_enable_interface 		(const char *interface_id);
+void 			arv_disable_interface		(const char *interface_id);
 
 void 			arv_update_device_list 		(void);
 unsigned int 		arv_get_n_devices 		(void);
