@@ -1,5 +1,3 @@
-#define GLIB_DISABLE_DEPRECATION_WARNINGS
-
 #include <arv.h>
 #include <stdlib.h>
 #include <string.h>
@@ -218,8 +216,8 @@ main (int argc, char **argv)
 	unsigned int i;
 	unsigned int count = 0;
 
-	g_thread_init (NULL);
-	g_type_init ();
+	arv_g_thread_init (NULL);
+	arv_g_type_init ();
 
 	context = g_option_context_new (" command <parameters>");
 	g_option_context_set_summary (context, "Small utility for basic control of a Genicam device.");
