@@ -250,6 +250,18 @@ swiss_knife_test (void)
 	value = arv_gc_integer_get_value (ARV_GC_INTEGER (node), NULL);
 	g_assert_cmpint (value, ==, 0x10305070);
 
+	node = arv_gc_get_node (genicam, "IntSwissKnifeTestEntity2");
+	g_assert (ARV_IS_GC_SWISS_KNIFE (node));
+
+	value = arv_gc_integer_get_value (ARV_GC_INTEGER (node), NULL);
+	g_assert_cmpint (value, ==, 3);
+
+	node = arv_gc_get_node (genicam, "IntSwissKnifeBug699228");
+	g_assert (ARV_IS_GC_SWISS_KNIFE (node));
+
+	value = arv_gc_integer_get_value (ARV_GC_INTEGER (node), NULL);
+	g_assert_cmpint (value, ==, 4);
+
 	g_object_unref (device);
 }
 
@@ -344,7 +356,7 @@ main (int argc, char *argv[])
 
 	g_test_init (&argc, &argv, NULL);
 
-	g_type_init ();
+	arv_g_type_init ();
 
 	arv_set_fake_camera_genicam_filename (GENICAM_FILENAME);
 
